package com.usky.fire.controller.web;


import com.usky.common.core.bean.ApiResult;
import com.usky.fire.service.PatrolInspectionPlanSonService;
import com.usky.fire.service.vo.PatrolInspectionPlanSonVo;
import com.usky.fire.service.vo.PlanRecordVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * APP-巡检
 *
 * @author JCB
 * @since 2022-07-12
 */
@RestController
@RequestMapping("/appPatrolInspection")
public class AppPatrolInspectionController {

    @Autowired
    private PatrolInspectionPlanSonService patrolInspectionPlanSonService;

    /**
     * App-巡检自查-首页
     *
     * @param personnelId 人员ID
     * @return
     */
    @GetMapping("appPlanStatistics")
    public ApiResult<Map<String, Object>> appPlanStatistics(@RequestParam(value = "personnelId") Integer personnelId,
                                                            @RequestParam(value = "currentDate", required = false) String currentDate) {
        return ApiResult.success(patrolInspectionPlanSonService.appPlanStatistics(personnelId, currentDate));
    }


    /**
     * App-巡检自查-巡检计划
     *
     * @param personnelId 人员ID
     * @param currentDate 日期 格式：yyyy-MM-dd
     * @param sort        排序 （正序：ASC 倒序：DESC）
     * @return
     */
    @GetMapping("patrolInspectionPlan")
    public ApiResult<Map<String, Object>> patrolInspectionPlan(@RequestParam(value = "personnelId") Integer personnelId,
                                                               @RequestParam(value = "currentDate", required = false) String currentDate,
                                                               @RequestParam(value = "sort", required = false, defaultValue = "DESC") String sort) {
        return ApiResult.success(patrolInspectionPlanSonService.patrolInspectionPlan(personnelId, currentDate, sort));
    }

    /**
     * 手机端-巡检自检-巡检计划-扫码查询计划
     *
     * @param personnelId 人员ID
     * @param siteNubmber 地点号码
     * @return
     */
    @GetMapping("planList")
    public ApiResult<List<PatrolInspectionPlanSonVo>> planList(@RequestParam(value = "personnelId") Integer personnelId,
                                                               @RequestParam(value = "siteNubmber") String siteNubmber) {
        return ApiResult.success(patrolInspectionPlanSonService.planList(siteNubmber, personnelId));
    }


    /**
     * 手机端-巡检自检-巡检扫码地点详情
     *
     * @param siteId      地点ID
     * @param siteNubmber 地点号码
     * @return
     */
    @GetMapping("siteDetails")
    public ApiResult<Map<String, Object>> siteDetails(@RequestParam(value = "siteId") Integer siteId,
                                                      @RequestParam(value = "siteNubmber") String siteNubmber) {
        return ApiResult.success(patrolInspectionPlanSonService.siteDetails(siteId, siteNubmber));
    }


    /**
     * 手机端-巡检自检-巡检上报-提交
     *
     * @param planRecordVo
     * @return
     */
    @PostMapping("updatePlan")
    public ApiResult<Void> updatePlan(@RequestBody PlanRecordVo planRecordVo) {
        patrolInspectionPlanSonService.updatePlan(planRecordVo);
        return ApiResult.success();
    }
}